Erik Johnston <erik at matrix.org>
 * HS core
 * Federation API impl

Mark Haines <mark at matrix.org>
 * HS core
 * Crypto
 * Content repository
 * CS v2 API impl

Kegan Dougal <kegan at matrix.org>
 * HS core
 * CS v1 API impl
 * AS API impl

Paul "LeoNerd" Evans <paul at matrix.org>
 * HS core
 * Presence
 * Typing Notifications
 * Performance metrics and caching layer

Dave Baker <dave at matrix.org>
 * Push notifications
 * Auth CS v2 impl

Matthew Hodgson <matthew at matrix.org>
 * General doc & housekeeping
 * Vertobot/vertobridge matrix<->verto PoC

Emmanuel Rohee <manu at matrix.org>
 * Supporting iOS clients (testability and fallback registration)

Turned to Dust <dwinslow86 at gmail.com>
 * ArchLinux installation instructions

Brabo <brabo at riseup.net>
 * Installation instruction fixes

Ivan Shapovalov <intelfx100 at gmail.com>
 * contrib/systemd: a sample systemd unit file and a logger configuration

Eric Myhre <hash at exultant.us>
 * Fix bug where ``media_store_path`` config option was ignored by v0 content
   repository API.

Muthu Subramanian <muthu.subramanian.karunanidhi at ericsson.com>
 * Add SAML2 support for registration and login.

Steven Hammerton <steven.hammerton at openmarket.com>
 * Add CAS support for registration and login.

Mads Robin Christensen <mads at v42 dot dk>
 * CentOS 7 installation instructions.

Florent Violleau <floviolleau at gmail dot com>
 * Add Raspberry Pi installation instructions and general troubleshooting items

Niklas Riekenbrauck <nikriek at gmail dot.com>
 * Add JWT support for registration and login

Christoph Witzany <christoph at web.crofting.com>
 * Add LDAP support for authentication

Pierre Jaury <pierre at jaury.eu>
* Docker packaging

Serban Constantin <serban.constantin at gmail dot com>
 * Small bug fix

Jason Robinson <jasonr at matrix.org>
 * Minor fixes

Joseph Weston <joseph at weston.cloud>
 + Add admin API for querying HS version

Benjamin Saunders <ben.e.saunders at gmail dot com>
 * Documentation improvements
